---
title: Api
order: 6
docGenIncludes:
  - src/components/YwJsonForm/index.tsx
---

```ts
export interface YwJsonFormProps {
  /** 表单项. */
  items: IItem[];
  /** 表单默认值. */
  initialValues: any;
  /** 操作项 */
  buttons?: IButtons[];
  /** 表单布局项 */
  layoutProps?: ILayoutProps;
  /** 表单尺寸 */
  size?: 'small' | 'default' | 'large';
  /** 是否可编辑（预览态） */
  editable?: Form['editable'];
  /** 是否禁用 */
  disabled?: Form['disabled'];
  /** 表单联动逻辑 */
  linkages?: ILinkages[];
  /** 提交回调 */
  onSubmit?: (values: Form['values']) => void;
  /** 创建回调 */
  onCreate?: (form: Form) => void;
  /** form 示例，不传入组件内部创建 */
  form?: Form;
}

export interface IButtons {
  htmlType: 'submit' | 'reset' | 'button';
  children?: React.ReactNode;
  type?: 'primary' | 'link' | 'default';
}

export interface ILayoutProps {
  style?: StyleSheet;
  className?: string;
  labelAlign?: 'right' | 'left' | Array<'right' | 'left'>;
  full?: boolean;
  labelCol?: number | number[];
  wrapperCol?: number | number[];
  labelWidth?: number;
  wrapperWidth?: number;
  columns?: number;
  grid?: boolean;
  autoRow?: boolean;
}
export interface IItem {
  /** 标签名 */
  title?: string;
  /** 字段名 */
  name?: string;
  /** 组件名 */
  component?:
    | 'Input'
    | 'Radio'
    | 'Switch'
    | 'NumberPicker'
    | 'Select'
    | 'TimePicker'
    | 'ArrayCards'
    | 'ArrayTable'
    | 'Cascader'
    | 'Checkbox'
    | 'DatePicker'
    | 'DateRangePicker'
    | 'FormGrid'
    | 'FormGroup';
  /** 自定义组件 */
  customComponent?: React.ReactNode;
  /** 组件入参 */
  componentProps?: object;
  /** 校验规则 */
  rules?: any;
  /** 默认值 */
  defaultValue?: any;
  /** 表单项类型 */
  type?: SchemaTypes;
  /** 是否只读 */
  disabled?: boolean | Function;
  /** 表单项入参 */
  props?: any;
  /** 子表单项 */
  children?: any;
  /** 是否必填 */
  required?: boolean;
  /** 描述信息 */
  description?: ISchema['description'];
  /** 枚举值 */
  enum?: SchemaEnum;
  /** 异步数据源请求uri */
  getDataSource?: Function;
  readOnly?: boolean;
  /** 是否显示 */
  visible?: boolean;
  /** 表单装饰器 */
  decorator?: ISchema['x-decorator'];
  /** 字段阅读态 */
  preview?: ISchema['x-read-pretty'];
}




``` 