---
title: 基础表单用法
order: 1
---

```jsx
import React, { useState,useEffect } from 'react';
import ReactDOM from 'react-dom';
import { YwJsonForm } from '@ywfe/yw-design';
import 'antd/dist/antd.css';
// import { YUpload } from "@ywfe/ywd";
const UploadImage = ({field,...props}) => {
  // div 替换成 YUpload 
    return (
      <div
        {...props}
        uploadFinish={(res) => {
          // 上传完成事件
          field.setValue(res.url);
        }}
        onChange={(res) => {
          // 监听移除事件
          if (res.length === 0) {
            field.setValue("");
          }
        }}
      >{JSON.stringify(props)}</div>
    );
  };

const items = [
  {
    title: '输入框',
    name: 'input',
    component: 'Input',
    type: 'string',
    disabled: true,
    tooltip: '123',
  },
  {
    title: '下拉框',
    name: 'select',
    component: 'Select',
    type: 'string',
    enum: [
      { value: 1, label: 1 },
      { value: 2, label: 2 },
    ],
    componentProps: {},
  },
  {
    title: '级联',
    name: 'cascader',
    component: 'Cascader',
    type: 'string',
    enum: [
  {
    value: 'zhejiang',
    label: 'Zhejiang',
    children: [
      {
        value: 'hangzhou',
        label: 'Hangzhou',
        children: [
          {
            value: 'xihu',
            label: 'West Lake',
          },
        ],
      },
    ],
  },
  {
    value: 'jiangsu',
    label: 'Jiangsu',
    children: [
      {
        value: 'nanjing',
        label: 'Nanjing',
        children: [
          {
            value: 'zhonghuamen',
            label: 'Zhong Hua Men',
          },
        ],
      },
    ],
  },
    ],
  },
  {
    title: '异步数据下拉框',
    name: 'asnySelect',
    component: 'Select',
    type: 'string',
    props: {
      fullness: false,
    },
    getDataSource: async () => {
      return new Promise((resolve) => {
        setTimeout(() => {
          resolve([
            {
              label: 'AAA',
              value: 'aaa',
            },
            {
              label: 'BBB',
              value: 'ccc',
            },
          ]);
        }, 1500);
      });
    },
  },
  {
    title: '异步搜索选择框',
    name: 'asnySearchSelect',
    component: 'SearchSelect',
    type: 'array',
    required:true,
    props: {
      fullness: false,
    },
    // defaultValue:{
    //             label: 'AAA',
    //             value: 'aaa',
    //           },
    componentProps:{
      placeholder:'请输入',
      mode:'multiple',
      getDataSource: async (keyword) => {
        return new Promise((resolve) => {
          setTimeout(() => {
            resolve([
              {
                label: 'AAA',
                value: 'aaa',
              },
              {
                label: 'BBB',
                value: 'ccc',
              },
            ]);
          }, 1500);
        });
      },
    }
  },
  {
    type: 'boolean',
    title: '是否确认',
    component: 'Switch',
  },
  {
    type: 'number',
    name: 'radio',
    title: '单选',
    enum: [
      {
        label: '选项1',
        value: 1,
      },
      {
        label: '选项2',
        value: 2,
      },
    ],
    component: 'RadioGroup',
  },
  {
    type: 'array',
    name: 'multiple',
    title: '复选',
    enum: [
      {
        label: '选项1',
        value: 1,
      },
      {
        label: '选项2',
        value: 2,
      },
    ],
    component: 'CheckboxGroup',
  },
  {
    type: 'string',
    name: 'multiple',
    title: '复选',
    enum: [
      {
        label: '选项1',
        value: 1,
      },
      {
        label: '选项2',
        value: 2,
      },
    ],
    component: 'CheckboxGroup',
  },
  {
    type: 'string',
    name: 'multiple',
    title: '复选',
    enum: [
      {
        label: '选项1',
        value: 1,
      },
      {
        label: '选项2',
        value: 2,
      },
    ],
    component: 'CheckboxGroup',
  },
  {
    type: 'string',
    name: 'inputGroup',
    title: '输入框组合',
    defaultValue:'createTime',
    enum: [
      { value: 'orderTime', label: '下单时间' },
      { value: 'createTime', label: '创建时间' },
    ],
    required:true,
    component: 'InputGroup',
    children:[
      {
       type: 'array',
        title: '',
        name: '[startDate,endDate]',
        required:true,
        component: 'DateRangePicker',
        defaultValue: ['2022-07-09', '2022-07-23'],
        componentProps: {
          ranges: ['昨天', '今天', '7天', '30天'],
          allowClear:true
        },
    }
    ]
  },
  {
    type: 'string',
    name: 'upload',
    title: '上传图片',
    customComponent: UploadImage,
    required:true,
    componentProps:{
      errMessage:'支持.jpg,.gif,.png,.jpeg格式，最多1张图片',
      quantity:1,
      value:'',
      disabled:false,
      isOss:true,
      multiple:false,
      accept:'.jpg,.gif,.png,.jpeg',
    }
  },
  {
    type: 'string',
    name: 'textArea',
    title: '多行编辑器', 
    component: 'TextArea',
  },

];
const buttons = [{ htmlType: 'submit' }, { htmlType: 'reset' }];


let form = null;


const onSubmit = (form) => {
  console.log('submit', form);
};

const onCreate = (_form) => {
  console.log('create', form);
  // form实例  Formily2.0  文档传送门 https://core.formilyjs.org/zh-CN/api/models/form
  form = _form 
  // 设置初始值
  form.setInitialValues({ input: 123 })
};


const App = () => {
  const [initialValues,setInitialValues] = useState({})
  const getFormData = async (props) => {
  return new Promise((resolve) => {
      setInitialValues({input:2222})
  });
};
  useEffect(()=>{
    getFormData()
  },[])
    return (
      <div>
        <YwJsonForm items={items} buttons={buttons} onCreate={onCreate} onSubmit={onSubmit} initialValues={initialValues}/>
      </div>
    );
}

ReactDOM.render(<App />, mountNode);
```
