import React, { useState, useMemo } from 'react';
import styles from "./index.module.less";
import { Button, Modal, Spin } from 'antd';
import { createForm } from '@formily/core';
import { YwJsonForm } from "../YwJsonForm";
import { isFunction } from "../../utils";
var widthMap = {
  s: 680,
  m: 920,
  l: 1200,
  full: '100vw'
};

var YwFormDialog = function YwFormDialog(_ref) {
  var title = _ref.title,
      size = _ref.size,
      btnText = _ref.btnText,
      btnType = _ref.btnType,
      items = _ref.items,
      disabled = _ref.disabled,
      editable = _ref.editable,
      initialValues = _ref.initialValues,
      layoutProps = _ref.layoutProps,
      btnDisabled = _ref.btnDisabled,
      children = _ref.children,
      onCancel = _ref.onCancel,
      onConfirm = _ref.onConfirm,
      onOpen = _ref.onOpen;

  var _useState = useState(false),
      visible = _useState[0],
      setVisible = _useState[1];

  var _useState2 = useState(false),
      spinning = _useState2[0],
      setSpinning = _useState2[1];

  var _useState3 = useState(false),
      confirmLoading = _useState3[0],
      setConfirmLoading = _useState3[1];

  var form = useMemo(function () {
    return createForm({
      disabled: disabled,
      editable: editable,
      initialValues: initialValues,
      effects: function effects(form) {}
    });
  }, []);

  var showModal = function showModal() {
    setVisible(true);

    if (isFunction(onOpen)) {
      setSpinning(true);
      onOpen().then(function (initialValues) {
        form.setValues(initialValues);
      })["finally"](function () {
        setSpinning(false);
      });
    }
  };

  var handleOk = function handleOk() {
    form.submit().then(function (value) {
      setConfirmLoading(true);
      onConfirm(value)["finally"](function () {
        setVisible(false);
        setConfirmLoading(false);
      });
    });
  };

  var handleCancel = function handleCancel() {
    setVisible(false);
    onCancel();
  };

  return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement("div", {
    onClick: showModal,
    style: {
      display: 'inline-block'
    }
  }, children || /*#__PURE__*/React.createElement(Button, {
    type: btnType,
    disabled: btnDisabled
  }, btnText)), /*#__PURE__*/React.createElement(Modal, {
    wrapClassName: styles['yw-form-dialog'],
    title: title,
    width: widthMap[size],
    visible: visible,
    onOk: handleOk,
    okText: "\u786E\u5B9A" // cancelText={editable ? '取消' : '关闭'}
    ,
    confirmLoading: confirmLoading,
    onCancel: handleCancel,
    footer: [/*#__PURE__*/React.createElement(Button, {
      key: "back",
      onClick: handleCancel
    }, editable ? '取消' : '关闭'), editable ? [/*#__PURE__*/React.createElement(Button, {
      key: "submit",
      type: "primary",
      loading: confirmLoading,
      onClick: handleOk
    }, "\u786E\u5B9A")] : []]
  }, /*#__PURE__*/React.createElement(Spin, {
    spinning: spinning
  }, /*#__PURE__*/React.createElement(YwJsonForm, {
    items: items,
    form: form,
    layoutProps: layoutProps,
    buttons: []
  }))));
};

YwFormDialog.defaultProps = {
  btnType: 'primary',
  size: 's',
  btnDisabled: false,
  editable: true,
  onCancel: function onCancel() {},
  onConfirm: function onConfirm() {}
};
export default YwFormDialog;