import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/objectWithoutPropertiesLoose";
import _extends from "@babel/runtime/helpers/extends";
var _excluded = ["ranges"];
import React, { useState } from 'react';
import { DatePicker as YDatePicker } from '@formily/antd';
import locale from 'antd/es/date-picker/locale/zh_CN';
import { isArrayField } from '@formily/core';
import moment from 'moment'; // import 'moment/locale/zh-cn';

import { useField } from '@formily/react'; // moment.locale('zh-cn', {
//   week: {
//     dow: 1,
//   },
// });

var RangePicker = YDatePicker.RangePicker;
var common = {
  locale: locale
};
var RANGES = {
  昨天: [moment().subtract(1, 'days'), moment()],
  今天: [moment(), moment()],
  '7天': [moment().subtract(6, 'days'), moment()],
  '15天': [moment().subtract(15, 'days'), moment().endOf('month')],
  '30天': [moment().subtract(30, 'days'), moment().endOf('month')]
};

var formatProps = function formatProps(props) {
  return _extends({}, common, {
    allowClear: true
  }, props);
};

var formatRangeProps = function formatRangeProps(props) {
  return _extends({}, common, {
    allowClear: true
  }, props);
}; // 日期选择


export var DatePicker = function DatePicker(props) {
  var _props = formatProps(_extends({}, props, {
    picker: 'date'
  }));

  var field = useField();

  var _useState = useState(isArrayField(field) ? props.value[0] || '' : props.value || ''),
      value = _useState[0],
      setValue = _useState[1];

  return /*#__PURE__*/React.createElement(YDatePicker, _extends({
    format: "YYYY-MM-DD"
  }, _props, {
    value: value,
    onChange: function onChange(date) {
      isArrayField(field) ? field.setValue([date + " 00:00:00", date + " 23:59:59"]) : field.setValue(date);
      setValue(date);
    }
  }));
}; // 日期时间选择

export var DateTimePicker = function DateTimePicker(props) {
  var _props = formatProps(_extends({}, props, {
    picker: 'date',
    showTime: {
      hideDisabledOptions: true,
      defaultValue: props.defaultTime ? moment(props.defaultTime, 'HH:mm:ss') : moment('00:00:00', 'HH:mm:ss')
    }
  }));

  var field = useField();

  var _useState2 = useState(isArrayField(field) ? props.value[0] || '' : props.value || ''),
      value = _useState2[0],
      setValue = _useState2[1];

  return /*#__PURE__*/React.createElement(YDatePicker, _extends({
    format: "YYYY-MM-DD HH:mm:ss"
  }, _props, {
    value: value,
    onChange: function onChange(date) {
      setValue(date);
      isArrayField(field) ? field.setValue([date, date]) : field.setValue(date);
    }
  }));
}; // 月选择

export var MonthPicker = function MonthPicker(props) {
  var _props = formatProps(_extends({}, props, {
    picker: 'month'
  }));

  var field = useField();

  var _useState3 = useState(isArrayField(field) ? props.value[0] || '' : props.value || ''),
      value = _useState3[0],
      setValue = _useState3[1];

  return /*#__PURE__*/React.createElement(YDatePicker, _extends({}, _props, {
    value: value,
    onChange: function onChange(date) {
      setValue(date);
      isArrayField(field) ? field.setValue([moment(date, 'YYYY-MM').startOf('month').format('YYYY-MM-DD'), moment(date, 'YYYY-MM').endOf('month').format('YYYY-MM-DD')]) : field.setValue(date);
    }
  }));
};
export var WeekPicker = function WeekPicker(props) {
  var _props = formatProps(_extends({}, props, {
    picker: 'week'
  }));

  var field = useField();

  var _useState4 = useState(isArrayField(field) ? props.value[0] || '' : props.value || ''),
      value = _useState4[0],
      setValue = _useState4[1];

  return /*#__PURE__*/React.createElement(YDatePicker, _extends({}, _props, {
    value: value,
    onChange: function onChange(date) {
      setValue(date);
      field.setValue([moment(date, 'YYYY-ww').startOf('week').format('YYYY-MM-DD'), moment(date, 'YYYY-ww').endOf('week').format('YYYY-MM-DD')]);
    }
  }));
}; // range

export var WeekRangePicker = function WeekRangePicker(props) {
  var _props = formatRangeProps(_extends({}, props, {
    picker: 'week'
  }));

  var field = useField();

  var formatWeek = function formatWeek(date) {
    var _date;

    if (date === void 0) {
      date = [];
    }

    if (!((_date = date) !== null && _date !== void 0 && _date.length)) return [];
    return [moment(props.value[0], 'YYYY-MM-DD').format('YYYY-wo'), moment(props.value[1], 'YYYY-MM-DD').format('YYYY-wo')];
  };

  var _useState5 = useState(formatWeek(props.value)),
      value = _useState5[0],
      setValue = _useState5[1];

  return /*#__PURE__*/React.createElement(RangePicker, _extends({
    separator: "-"
  }, _props, {
    value: value,
    onChange: function onChange(date) {
      setValue(date);
      field.setValue([moment(date[0], 'YYYY-ww').startOf('week').format('YYYY-MM-DD'), moment(date[1], 'YYYY-ww').endOf('week').format('YYYY-MM-DD')]);
    }
  }));
};
export var DateRangePicker = function DateRangePicker(_ref) {
  var ranges = _ref.ranges,
      props = _objectWithoutPropertiesLoose(_ref, _excluded);

  var _ranges = Array.isArray(ranges) ? ranges.reduce(function (curr, prev) {
    if (!RANGES[prev]) {
      return curr;
    }

    curr[prev] = RANGES[prev];
    return curr;
  }, {}) : ranges || {};

  var _props = formatRangeProps(_extends({}, props, {
    ranges: _ranges,
    picker: 'date'
  }));

  return /*#__PURE__*/React.createElement(RangePicker, _extends({
    separator: "-"
  }, _props));
};
export var MonthRangePicker = function MonthRangePicker(props) {
  var _props$value;

  var _props = formatRangeProps(_extends({}, props, {
    picker: 'month'
  }));

  var field = useField();

  var _initValue = ((_props$value = props.value) === null || _props$value === void 0 ? void 0 : _props$value.length) > 0 ? [moment(props.value[0]).startOf('month').format('YYYY-MM'), moment(props.value[1]).startOf('month').format('YYYY-MM')] : [];

  var _useState6 = useState(_initValue),
      value = _useState6[0],
      setValue = _useState6[1];

  return /*#__PURE__*/React.createElement(RangePicker, _extends({
    separator: "-"
  }, _props, {
    value: value,
    onChange: function onChange(date) {
      setValue(date);
      field.setValue([moment(date[0]).startOf('month').format('YYYY-MM-DD'), moment(date[1]).endOf('month').format('YYYY-MM-DD')]);
    }
  }));
};
export var DateTimeRangePicker = function DateTimeRangePicker(props) {
  var _props$defaultTime;

  var _props = formatRangeProps(_extends({}, props, {
    picker: 'date',
    showTime: {
      hideDisabledOptions: true,
      defaultValue: ((_props$defaultTime = props.defaultTime) === null || _props$defaultTime === void 0 ? void 0 : _props$defaultTime.length) > 0 ? [moment(props.defaultTime[0], 'HH:mm:ss'), moment(props.defaultTime[1], 'HH:mm:ss')] : [moment('00:00:00', 'HH:mm:ss'), moment('23:59:59', 'HH:mm:ss')]
    }
  }));

  return /*#__PURE__*/React.createElement(RangePicker, _extends({
    format: "YYYY-MM-DD HH:mm:ss",
    separator: "-"
  }, _props));
};