import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/objectWithoutPropertiesLoose";
var _excluded = ["CustomComponent"],
    _excluded2 = ["buttons", "onCreate", "onSubmit", "editable", "disabled", "size", "layoutProps", "buttonsProps", "items", "initialValues", "linkActions", "valueChangeforLink"];
import React, { useMemo, Fragment, useEffect } from 'react';
import { createForm, onFormInit, onFormValuesChange, registerValidateRules, registerValidateFormats } from '@formily/core';
import { Input, FormItem, FormButtonGroup, Submit, Reset, NumberPicker, Select, Switch, FormLayout, FormGrid, Radio, Checkbox, Cascader } from '@formily/antd';
import { FormProvider, createSchemaField, useField, useFieldSchema } from '@formily/react';
import YwTitle from "../YwTitle";
import { useAsyncDataSource } from "./hook";
import { LinkProvider, useLink } from '@ywfe/yw-linkage';
import { WeekRangePicker, DateRangePicker, MonthRangePicker, DateTimeRangePicker, MonthPicker, WeekPicker, DatePicker, DateTimePicker } from "./YDatePicker";
import YInputGroup from "./YInputGroup";
import YArrayTable from "./YArrayTable";
import YSearchSelect from "./YSearchSelect";
import { FORMATS, RULES } from "./rules";
import styles from "./index.module.less";
var TextArea = Input.TextArea;
var RadioGroup = Radio.Group;
var CheckboxGroup = Checkbox.Group; // let customComponent: any[] = [];

var dataSource = {};
registerValidateFormats(FORMATS);
registerValidateRules(RULES);

var customComponent = function customComponent(props) {
  var field = useField();
  var schema = useFieldSchema();

  var _ref = schema['x-component-props'] || {},
      CustomComponent = _ref.CustomComponent,
      rest = _objectWithoutPropertiesLoose(_ref, _excluded);

  return CustomComponent && /*#__PURE__*/React.createElement(CustomComponent, _extends({}, rest, {
    field: field
  }));
};

var SchemaField = createSchemaField({
  components: {
    Input: Input,
    FormItem: FormItem,
    FormLayout: FormLayout,
    Select: Select,
    RadioGroup: RadioGroup,
    TextArea: TextArea,
    Switch: Switch,
    CheckboxGroup: CheckboxGroup,
    NumberPicker: NumberPicker,
    FormGrid: FormGrid,
    Cascader: Cascader,
    WeekRangePicker: WeekRangePicker,
    DateRangePicker: DateRangePicker,
    MonthRangePicker: MonthRangePicker,
    MonthPicker: MonthPicker,
    WeekPicker: WeekPicker,
    DatePicker: DatePicker,
    DateTimeRangePicker: DateTimeRangePicker,
    DateTimePicker: DateTimePicker,
    InputGroup: YInputGroup,
    ArrayTable: YArrayTable,
    SearchSelect: YSearchSelect // ...customComponent,

  }
});

var formatSchema = function formatSchema(item) {
  if (item === void 0) {
    item = {};
  }

  // if (item.customComponent) {
  //   customComponent = [...customComponent, item.customComponent];
  // }
  if (item.getDataSource) {
    dataSource[item.name] = item.getDataSource;
  }

  return _extends({
    type: item.type || 'void',
    title: item.title,
    description: item.description,
    "default": item.defaultValue,
    readOnly: item.readOnly,
    "enum": item["enum"],
    required: item.required,
    'x-validator': item.rules,
    'x-decorator': item.decorator || 'FormItem',
    'x-decorator-props': _extends({}, item.props, {
      getDataSource: item.getDataSource
    })
  }, item.getDataSource ? {
    'x-reactions': ['{{useAsyncDataSource(dataSource)}}']
  } : {}, {
    'x-component': item.customComponent ? customComponent : item.component,
    'x-component-props': _extends({}, item.componentProps, item.customComponent ? {
      CustomComponent: item.customComponent
    } : {}),
    'x-visible': item.visible,
    'x-disabled': item.disabled,
    'x-read-pretty': item.preview
  });
};

function YwJsonForm(props) {
  var buttons = props.buttons,
      onCreate = props.onCreate,
      onSubmit = props.onSubmit,
      editable = props.editable,
      disabled = props.disabled,
      size = props.size,
      layoutProps = props.layoutProps,
      buttonsProps = props.buttonsProps,
      items = props.items,
      initialValues = props.initialValues,
      linkActions = props.linkActions,
      valueChangeforLink = props.valueChangeforLink,
      others = _objectWithoutPropertiesLoose(props, _excluded2);

  var _useLink = useLink(),
      when = _useLink.when,
      run = _useLink.run,
      registerActions = _useLink.registerActions,
      dispatch = _useLink.dispatch;

  var form = props.form || useMemo(function () {
    return createForm({
      disabled: disabled,
      editable: editable,
      effects: function effects(form) {
        onFormInit(function () {
          onCreate(form);
        });
        onFormValuesChange(function (form) {
          valueChangeforLink && valueChangeforLink(form.values, dispatch); // console.log('change', jsonLogic.apply({ '==': [form.values.source, true]) );
          // onValueChange('change', form.values);
        });
      }
    });
  }, []);

  var FormGroup = function FormGroup(props) {
    return /*#__PURE__*/React.createElement(Fragment, null, /*#__PURE__*/React.createElement(YwTitle, {
      size: props.size,
      text: props.text
    }), /*#__PURE__*/React.createElement(FormLayout, _extends({}, layoutProps, {
      size: size,
      style: {
        marginTop: '20px'
      }
    }), props.children));
  };

  var getItemsSchema = function getItemsSchema() {
    var formatItem = function formatItem(nodeList) {
      if (nodeList.length === 0) {
        return null;
      }

      var res = {};
      nodeList.forEach(function (item, idx) {
        if (item.component === 'FormGroup') {
          // 分组标题
          res["NO_FIELD_NAME_" + idx] = _extends({
            type: 'void',
            'x-component': FormGroup,
            'x-decorator': 'FormItem',
            'x-visible': item.visible,
            'x-component-props': {
              size: size === 'small' ? 's' : 'm',
              text: item.title
            }
          }, item.children ? formatItem(item.children) : {});
        } else if (item.component === 'FormGrid') {
          // grid
          res["NO_FIELD_NAME_" + idx] = _extends({}, formatSchema(item), item.children ? formatItem(item.children) : {});
        } else if (item.component === 'ArrayTable') {
          // ArrayTable
          res[item.name] = _extends({}, formatSchema(item), {
            type: 'array',
            'x-component-props': _extends({}, item.componentProps, {
              layoutProps: layoutProps,
              arrayConfig: item.children
            })
          });
        } else {
          res[item.name] = _extends({}, formatSchema(item), item.children ? formatItem(item.children) : {});
        }
      });
      return {
        properties: res
      };
    };

    return formatItem(items || []);
  };

  var renderButtons = function renderButtons() {
    return buttons !== null && buttons !== void 0 && buttons.length ? /*#__PURE__*/React.createElement(FormButtonGroup.FormItem, null, buttons === null || buttons === void 0 ? void 0 : buttons.map(function (btn) {
      var _component = {
        submit: /*#__PURE__*/React.createElement(Submit, {
          key: "submit",
          onSubmit: onSubmit,
          size: size
        }, "\u63D0\u4EA4"),
        reset: /*#__PURE__*/React.createElement(Reset, {
          key: "reset",
          size: size
        }, "\u91CD\u7F6E"),
        button: btn.children
      };
      return _component[btn.htmlType];
    })) : null;
  };

  useEffect(function () {
    // linkActions && registerActions(linkActions);
    registerActions([{
      path: 'YwJsonForm',
      type: 'submit',
      execute: function execute(_ref2) {
        var _ref2$onSubmit = _ref2.onSubmit,
            onSubmit = _ref2$onSubmit === void 0 ? function () {} : _ref2$onSubmit;
        form.submit().then(function (value) {
          onSubmit(value);
        });
      }
    }]);
  });
  useEffect(function () {
    initialValues && form.setValues(initialValues);
  }, [initialValues]);
  return /*#__PURE__*/React.createElement("div", {
    className: styles['yw-json-form'],
    style: props.style
  }, /*#__PURE__*/React.createElement(FormProvider, {
    form: form
  }, /*#__PURE__*/React.createElement(LinkProvider, null, /*#__PURE__*/React.createElement(FormLayout, _extends({}, layoutProps, {
    size: size
  }), /*#__PURE__*/React.createElement(SchemaField, {
    schema: getItemsSchema(),
    scope: {
      useAsyncDataSource: useAsyncDataSource,
      dataSource: dataSource
    }
  }), buttonsProps.sticky ? /*#__PURE__*/React.createElement(FormButtonGroup.Sticky, {
    align: buttonsProps.align
  }, renderButtons()) : renderButtons()))));
} // let form = null;
// function YwJsonFormWithLink(props: YwJsonFormProps) {
//   const { linkages, ...rest } = props;
//   const _linkages = linkages.map((rule) => {
//     return {
//       type: 'command',
//       source: 'YwJsonForm',
//       event: rule.type === 'value' ? 'onChange' : 'state',
//       condition: rule.conditions,
//       actions: [
//         {
//           target: 'YwJsonForm',
//           action: rule.type,
//           params: {
//             conditions: rule.conditions,
//             targetState: rule.targetState,
//             targetValue: rule.targetValue,
//             target: rule.target,
//           },
//         },
//       ],
//     };
//   });
//   return (
//     <LinkProvider>
//       <LinkBlock linkages={_linkages} />
//       <YwJsonForm
//         onCreate={(_form) => {
//           form = _form;
//         }}
//         {...rest}
//         linkActions={[
//           {
//             path: 'YwJsonForm',
//             type: 'value',
//             execute: ({ conditions, targetValue, targetState, target }) => {
//               if (jsonLogic.apply(conditions, form.values)) {
//                 targetValue !== undefined && form.setValuesIn(target, targetValue);
//                 targetState !== undefined && form.setFieldState(target, targetState);
//               }
//             },
//           },
//           {
//             path: 'YwJsonForm',
//             type: 'dataSource',
//             execute: ({ conditions, targetValue, targetState = {}, target }) => {
//               const { dataSource } = targetState;
//               if (jsonLogic.apply(conditions, form.values)) {
//                 form.setValuesIn(target, '');
//                 dataSource !== undefined && form.setFieldState(target, { dataSource });
//               }
//             },
//           },
//           {
//             path: 'YwJsonForm',
//             type: 'visible',
//             execute: ({ conditions, target }) => {
//               if (jsonLogic.apply(conditions, form.values)) {
//                 form.setFieldState(target, { visible: false });
//               } else {
//                 form.setFieldState(target, { visible: true });
//               }
//             },
//           },
//           {
//             path: 'YwJsonForm',
//             type: 'disabled',
//             execute: ({ conditions, target }) => {
//               if (jsonLogic.apply(conditions, form.values)) {
//                 form.setFieldState(target, { disabled: true });
//               } else {
//                 form.setFieldState(target, { disabled: false });
//               }
//             },
//           },
//         ]}
//         valueChangeforLink={(values, dispatch) => {
//           linkages.forEach(({ conditions = {}, ...rule }) => {
//             if (rule.type === 'value') {
//               dispatch({
//                 path: 'YwJsonForm',
//                 type: 'onChange',
//               });
//             } else {
//               dispatch({
//                 path: 'YwJsonForm',
//                 type: 'state',
//               });
//             }
//           });
//         }}
//       />
//     </LinkProvider>
//   );
// }


YwJsonForm.defaultProps = {
  form: null,
  layoutProps: {
    // labelAlign: 'right',
    labelCol: 6,
    wrapperCol: 10 // inset: true,
    // inline: true,
    // layout:['vertical', 'horizontal','inline'],

  },
  linkages: [],
  buttons: [{
    htmlType: 'submit'
  }, {
    htmlType: 'reset'
  }],
  buttonsProps: {},
  onSubmit: function onSubmit(form) {
    console.log('submit', form);
  },
  onCreate: function onCreate(form) {// console.log('表单初始化', form)
    // form.setInitialValues({ input: 123333 })
  } // onValueChange: (data, form) => {
  // form.setInitialValues({ input: 123333 })
  // },

}; // YwJsonForm.displayName = 'YwJsonForm';

export { YwJsonForm };