import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/objectWithoutPropertiesLoose";
var _excluded = ["component", "componentProps", "formatValues"],
    _excluded2 = ["visible"],
    _excluded3 = ["visible"],
    _excluded4 = ["columns", "buttons", "getTableData", "filterProps"];
import React, { useState, useEffect, useMemo } from 'react';
import { Table, Button, Dropdown, Menu } from 'antd';
import { DownOutlined } from '@ant-design/icons';
import styles from "./index.module.less";
import { Person, Time, Status, Operates, Tags, MultipleCol } from "./components/index";
import { DetailInfo, LongText2Ellipsis } from "./components/detailInfo";
import usePagination from "./usePagination";
import { isVisible, isDisabled } from "../../utils/index";
var registerCom = {
  MultipleCol: MultipleCol,
  Time: Time,
  Person: Person,
  Status: Status,
  Operates: Operates,
  Tags: Tags,
  DetailInfo: DetailInfo,
  LongText2Ellipsis: LongText2Ellipsis
};

var formatColumns = function formatColumns(_columns, _ref) {
  if (_columns === void 0) {
    _columns = [];
  }

  var reload = _ref.reload;
  return _columns.map(function (_ref2) {
    var _ref2$component = _ref2.component,
        component = _ref2$component === void 0 ? '' : _ref2$component,
        componentProps = _ref2.componentProps,
        _ref2$formatValues = _ref2.formatValues,
        formatValues = _ref2$formatValues === void 0 ? null : _ref2$formatValues,
        item = _objectWithoutPropertiesLoose(_ref2, _excluded);

    if (!component) return item;
    return _extends({}, item, {
      render: function render(data, record, index) {
        var Component = registerCom[component] || null;

        if (formatValues) {
          var value = formatValues(data, record, index);
          return /*#__PURE__*/React.createElement(Component, _extends({
            value: value
          }, componentProps, {
            record: record,
            key: item.dataIndex
          }));
        }

        return /*#__PURE__*/React.createElement(Component, _extends({
          value: data
        }, componentProps, {
          record: record,
          reload: reload,
          key: item.dataIndex
        }));
      }
    });
  });
};

var formatBatchBtn = function formatBatchBtn(buttons, _ref3) {
  if (buttons === void 0) {
    buttons = [];
  }

  var hasSelect = _ref3.hasSelect,
      selectedRowKeys = _ref3.selectedRowKeys,
      selectedData = _ref3.selectedData,
      reload = _ref3.reload;
  return buttons.filter(function (v) {
    return v.type === 'batch' && isVisible(v.visible, null);
  }).map(function (_ref4, i) {
    var _ref4$visible = _ref4.visible,
        visible = _ref4$visible === void 0 ? true : _ref4$visible,
        v = _objectWithoutPropertiesLoose(_ref4, _excluded2);

    return visible && /*#__PURE__*/React.createElement(Button, {
      key: i,
      disabled: !hasSelect || isDisabled(v.disabled, null),
      onClick: function onClick() {
        v.onClick(selectedRowKeys, selectedData, reload);
      }
    }, v.btnText);
  });
};

var formatActionBtn = function formatActionBtn(buttons, _ref5) {
  if (buttons === void 0) {
    buttons = [];
  }

  var reload = _ref5.reload;
  return buttons.filter(function (v) {
    return v.type !== 'batch' && isVisible(v.visible, null);
  }).map(function (_ref6, i) {
    var _ref6$visible = _ref6.visible,
        visible = _ref6$visible === void 0 ? true : _ref6$visible,
        v = _objectWithoutPropertiesLoose(_ref6, _excluded3);

    if (v.btnType === 'dropdown') {
      var _v$dataSource;

      var menu = /*#__PURE__*/React.createElement(Menu, {
        onClick: function onClick(data) {
          v.onClick(data, reload);
        }
      }, (_v$dataSource = v.dataSource) === null || _v$dataSource === void 0 ? void 0 : _v$dataSource.map(function (_ref7) {
        var key = _ref7.key,
            label = _ref7.label;
        return /*#__PURE__*/React.createElement(Menu.Item, {
          key: key
        }, label);
      }));
      return visible && /*#__PURE__*/React.createElement(Dropdown, {
        overlay: menu
      }, /*#__PURE__*/React.createElement(Button, {
        disabled: isDisabled(v.disabled, null)
      }, v.btnText, " ", /*#__PURE__*/React.createElement(DownOutlined, null)));
    }

    return visible && /*#__PURE__*/React.createElement(Button, {
      key: i,
      type: v.btnType || 'primary',
      disabled: v.disabled,
      onClick: function onClick() {
        v.onClick(reload);
      }
    }, v.children || v.btnText);
  });
};

function YwTable(props) {
  var _props$rowSelection;

  var columns = props.columns,
      buttons = props.buttons,
      getTableData = props.getTableData,
      filterProps = props.filterProps,
      others = _objectWithoutPropertiesLoose(props, _excluded4);

  var _useState = useState(((_props$rowSelection = props.rowSelection) === null || _props$rowSelection === void 0 ? void 0 : _props$rowSelection.selectedRowKeys) || []),
      selectedRowKeys = _useState[0],
      setSelectedRowKeys = _useState[1];

  var _useState2 = useState([]),
      selectedData = _useState2[0],
      setSelectedData = _useState2[1];

  var rowSelection = props.rowSelection ? _extends({}, props.rowSelection, {
    selectedRowKeys: selectedRowKeys,
    onChange: function onChange(newSelectedRowKeys, data) {
      setSelectedRowKeys(newSelectedRowKeys);
      setSelectedData(data);
    }
  }) : null;
  var hasSelect = useMemo(function () {
    return !!(selectedRowKeys.length > 0);
  }, [selectedRowKeys]);

  var _usePagination = usePagination(function (_ref8, params) {
    var pageIndex = _ref8.pageIndex,
        pageSize = _ref8.pageSize;
    return getTableData(_extends({
      pageIndex: pageIndex,
      pageSize: pageSize
    }, params));
  }, {
    manual: true
  }),
      data = _usePagination.data,
      loading = _usePagination.loading,
      pagination = _usePagination.pagination,
      run = _usePagination.run,
      params = _usePagination.params;

  useEffect(function () {
    var _params$;

    run({
      pageIndex: 1,
      pageSize: ((_params$ = params[0]) === null || _params$ === void 0 ? void 0 : _params$.pageSize) || 20
    }, filterProps);
  }, [filterProps]);

  var reload = function reload() {
    setSelectedRowKeys([]);
    setSelectedData([]);
    run(params[0] || {}, params[1] || {});
  };

  return /*#__PURE__*/React.createElement("div", {
    className: styles['yw-table'] + " " + styles['yw-table-multiple'],
    style: props.style
  }, /*#__PURE__*/React.createElement("div", {
    className: styles["yw-table-btns"]
  }, /*#__PURE__*/React.createElement("div", {
    className: styles.batch
  }, rowSelection && /*#__PURE__*/React.createElement("span", {
    className: styles.total
  }, "\u5171\u9009\u4E2D ", selectedRowKeys.length, " \u6761 "), formatBatchBtn(buttons, {
    hasSelect: hasSelect,
    selectedRowKeys: selectedRowKeys,
    selectedData: selectedData,
    reload: reload
  })), /*#__PURE__*/React.createElement("div", {
    className: styles.action
  }, formatActionBtn(buttons, {
    reload: reload
  }))), /*#__PURE__*/React.createElement(Table, _extends({}, others, {
    columns: formatColumns(columns, {
      reload: reload
    }),
    dataSource: (data === null || data === void 0 ? void 0 : data.list) || [],
    loading: loading,
    pagination: _extends({}, pagination, props.pagination),
    rowSelection: rowSelection
  })));
}

YwTable.defaultProps = {
  multiple: true,
  stickyHeader: false,
  composite: true,
  pagination: {},
  buttons: [],
  rowSelection: null,
  columns: [],
  filterProps: {},
  getTableData: function getTableData() {}
};
export default YwTable;