/// <reference types="react" />
import type { Form } from '@formily/core';
import type { ISchema, SchemaEnum, SchemaTypes } from '@formily/react';
import type { TabsProps, TableProps } from 'antd';
export interface YwTitleProps {
    /** 主标题内容 */
    text: string;
    /** 副标题 */
    subtitle?: string;
    /** 标题尺寸 */
    size?: 'l' | 'm' | 's';
    /** 自定义内容 */
    children?: React.ReactNode;
    /** 样式 */
    style?: React.CSSProperties;
}
export declare type TabItem = {
    tab: string;
    key: string;
    content?: string | React.ReactNode;
    /** 红点提示 */
    dot?: boolean;
    /** 数量提示 */
    count?: number;
};
export interface YwTabProps extends TabsProps {
    /** 样式 */
    style?: React.CSSProperties;
    /** 形态 ，默认pure */
    shape?: 'pure' | 'wrapped' | 'capsule';
    /** tab项 */
    dataSource: Array<TabItem>;
}
export declare type ColumnItem = {
    /** 标题 */
    title: string | React.ReactNode;
    dataIndex: string;
    width?: number;
    /** 组件 */
    component?: 'MultipleCol' | 'Time' | 'Person' | 'Operates' | 'Status' | 'Tags' | 'DetailInfo' | 'LongText2Ellipsis';
    /** 组件入参 */
    componentProps?: object;
};
export declare type ButtonItem = {
    children?: string | React.ReactNode;
    btnText: string;
    btnType?: string;
    type: 'batch' | 'action';
    disabled?: boolean | Function;
    visible?: boolean | Function;
    onClick?: Function;
};
export interface YwTableProps<SearchProps, dataSourceProps> extends TableProps<dataSourceProps> {
    /** 表格筛选参数 */
    filterProps?: SearchProps;
    /** 样式 */
    style?: React.CSSProperties;
    /** Table列信息 同 antd columns*/
    columns: Array<ColumnItem>;
    /** 操作区配置项  */
    buttons?: Array<ButtonItem>;
    /** 获取数据 */
    getTableData: (params: SearchProps & {
        pageIndex: number;
        pageSize: number;
    }) => Promise<{
        totalNumber: number;
        pageIndex: number;
        pageSize: number;
        list: dataSourceProps;
    }>;
}
export interface IItem {
    /** 标签名 */
    title?: string;
    /** 字段名 */
    name?: string;
    /** 组件名 */
    component?: 'Input' | 'Radio' | 'Switch' | 'NumberPicker' | 'Select' | 'TimePicker' | 'ArrayCards' | 'ArrayTable' | 'Cascader' | 'Checkbox' | 'DatePicker' | 'DateRangePicker' | 'FormGrid' | 'FormGroup';
    /** 自定义组件 */
    customComponent?: React.ReactNode;
    /** 组件入参 */
    componentProps?: object;
    /** 校验规则 */
    rules?: any;
    /** 默认值 */
    defaultValue?: any;
    /** 表单项类型 */
    type?: SchemaTypes;
    /** 是否只读 */
    disabled?: boolean | Function;
    /** 表单项入参 */
    props?: any;
    /** 子表单项 */
    children?: any;
    /** 是否必填 */
    required?: boolean;
    /** 描述信息 */
    description?: ISchema['description'];
    /** 枚举值 */
    enum?: SchemaEnum<any>;
    /** 异步数据源请求uri */
    getDataSource?: Function;
    /** 是否只读 */
    readOnly?: boolean;
    /** 是否显示 */
    visible?: boolean;
    /** 表单装饰器 */
    decorator?: ISchema['x-decorator'];
    /** 字段阅读态 */
    preview?: ISchema['x-read-pretty'];
}
export interface ILayoutProps {
    style?: StyleSheet;
    className?: string;
    labelAlign?: 'right' | 'left' | Array<'right' | 'left'>;
    full?: boolean;
    labelCol?: number | number[];
    wrapperCol?: number | number[];
    labelWidth?: number;
    wrapperWidth?: number;
    columns?: number;
    grid?: boolean;
    autoRow?: boolean;
    colon?: boolean;
}
export interface IButtons {
    htmlType: 'submit' | 'reset' | 'button';
    children?: React.ReactNode;
    type?: 'primary' | 'link' | 'default';
}
export interface IButtonsProps {
    sticky: boolean;
    align: 'left' | 'center' | 'right';
}
export interface ILinkages {
    type: string;
    conditions: {
        key: string;
        value: string;
    };
    target: string;
    targetValue: string;
}
export interface YwJsonFormProps {
    /** 样式 */
    style?: React.CSSProperties;
    /** 表单项. */
    items: IItem[];
    /** 表单默认值. */
    initialValues?: any;
    /** 操作项 */
    buttons?: IButtons[];
    /** 表单布局项 */
    layoutProps?: ILayoutProps;
    /** 表单尺寸 */
    size?: 'small' | 'default' | 'large';
    /** 是否可编辑（预览态） */
    editable?: Form['editable'];
    /** 是否禁用 */
    disabled?: Form['disabled'];
    /** 操作项入参 */
    buttonsProps?: IButtonsProps;
    /** 表单联动逻辑 */
    linkActions?: ILinkages[];
    /** 表单联动逻辑 */
    valueChangeforLink?: (any: any, any: any) => {};
    /** 提交回调 */
    onSubmit?: (values: Form['values']) => void;
    /** 创建回调 */
    onCreate?: (form: Form) => void;
    /** form 示例，不传入组件内部创建 */
    form?: Form;
}
export interface YwFilterProps {
    /** 样式 */
    style?: React.CSSProperties;
    /** 表单配置项. */
    items: IItem[];
    /** 最多展示行数. */
    maxRows?: number;
    /** 最多展示列. */
    maxColumns?: number;
    /** 最少展示列. */
    minColumns?: number;
    /** 列间距. */
    columnGap?: number;
    /** 默认查询条件 */
    initialValues?: object;
    /** 表单项宽度 */
    itemWidth?: number;
    /** 是否开启缓存 */
    cache?: boolean;
    /** 提交回调 */
    onSubmit?: (values: Form['values']) => void;
    /** 重置 */
    onReset?: () => void;
}
export interface YwFormDialogProps {
    /** 自定义触发元素 */
    children?: React.ReactNode;
    /** 弹窗名称 */
    title: string;
    /** 弹窗尺寸 */
    size?: 's' | 'm' | 'l' | 'full';
    /** 按钮文字 */
    btnText?: string;
    /** 按钮类型 */
    btnType?: 'primary' | 'link' | 'text' | 'ghost' | 'default' | 'dashed';
    /** 按钮禁用 */
    btnDisabled?: boolean;
    /** 表单项 同YwJsonForm */
    items: IItem[];
    /** 表单是否禁用 */
    disabled?: boolean;
    /** 表单是否可编辑 */
    editable?: boolean;
    /** 表单布局 同YwJsonForm*/
    layoutProps?: ILayoutProps;
    /** 表单 初始值*/
    initialValues?: object;
    /** 取消回调*/
    onCancel?: () => {};
    /** 确认回调*/
    onConfirm?: (any: any) => Promise<any>;
    /** 弹窗打开回调*/
    onOpen?: () => Promise<any>;
}
